@@ -4,6 +4,7 @@ import os
 import re
 
 import pendulum
+import pkg_resources
 import psutil
 from psutil.tests import sh
 
@@ -205,6 +206,10 @@ def chia_version() -> str:
     return version
 
 
+def plotman_version() -> str:
+    return pkg_resources.get_distribution('plotmanx')
+
+
 def get_plot_progress(line_count: int) -> float:
     phase1_line_end = PROGRESS_BAR.get('phase1_line_end')
     phase2_line_end = PROGRESS_BAR.get('phase2_line_end')
